@@ -28,7 +28,8 @@
 #' arguments \code{control},\code{meta.data},and \code{method} are defined the
 #' same as in \code{ddf}.
 #'
-#' @S3method ddf io.fi
+#' @export
+#' @method ddf io.fi
 #' @param model mark-recapture model specification
 #' @param data analysis dataframe
 #' @param meta.data list containing settings controlling data structure
@@ -99,7 +100,7 @@ ddf.io.fi <- function(model,data,meta.data=list(),control=list(),
                                   int.range=NA, point=FALSE)
 
   # Set up control values
-  control <- assign.default.values(control,showit = 0, doeachint=FALSE,
+  control <- assign.default.values(control,showit = 0,
                                    estimate=TRUE,refit=TRUE,nrefits=25,
                                    initial = NA, lowerbounds = NA,
                                    upperbounds = NA, mono.points=20)
