@@ -126,7 +126,7 @@
 #' \item{clusters}{result list for object clusters}
 #' \item{individuals}{result list for individuals}
 #' \item{Expected.S}{\code{data.frame} of estimates of expected cluster size
-#'  with fields \code{Region}, \code{Expected.S} and \code{se.Expected.S})
+#'  with fields \code{Region}, \code{Expected.S} and \code{se.Expected.S}
 #'  If each cluster \code{size=1}, then the result only includes individuals
 #'  and not clusters and \code{Expected.S}.}
 #'
@@ -373,14 +373,15 @@ dht <- function(model,region.table,sample.table, obs.table=NULL, subset=NULL,
   # statement to be added to create obs.table from model data rather than
   # creating obs.table separately. This only works if the data contain the
   # Sample.Label and Region.Label fields.
-  #
-  # jll 3 Sept 2014 if dual observer I added code to use observer 1 only 
-  # or it was doubling sample size
   point <- model$meta.data$point
   objects <- as.numeric(names(model$fitted))
   if(is.null(obs.table)){
     data <- model$data
-	if("observer"%in%names(data)) data <- data[data$observer==1,]
+    if("observer"%in%names(data)){
+      # jll 3 Sept 2014 if dual observer I added code to use observer 1 only
+      # or it was doubling sample size
+      data <- data[data$observer==1,]
+    }
     if("Sample.Label" %in% names(data) & "Region.Label" %in% names(data)){
       if(is.null(substitute(subset))){
          obs.table <- data[,c("object","Sample.Label","Region.Label")]
@@ -390,7 +391,7 @@ dht <- function(model,region.table,sample.table, obs.table=NULL, subset=NULL,
       }
       obs.table <- obs.table[obs.table$object %in% objects,]
     }else{
-      stop("Must specify obs.table because Sample.Label and/or Region.Label fields not contained in ",model$data)
+      stop("Must specify obs.table because Sample.Label and/or Region.Label fields not contained in data")
     }
   }
 
